diff --git a/Octokit/Clients/StatisticsClient.cs b/Octokit/Clients/StatisticsClient.cs
index fba2c49c..382864ae 100644
--- a/Octokit/Clients/StatisticsClient.cs
+++ b/Octokit/Clients/StatisticsClient.cs
@@ -18,9 +18,9 @@ namespace Octokit
/// Returns a list of for the given repo
///
/// The owner of the repository
- /// The name of the repository
+ /// The name of the repository
/// A list of
- public Task> Contributors(string owner, string repoName)
+ public Task> Contributors(string owner, string repositoryName)
{
throw new NotImplementedException();
}
diff --git a/Octokit/Clients/IStatisticsClient.cs b/Octokit/Clients/IStatisticsClient.cs
index 4bd61ad6..6e937d80 100644
--- a/Octokit/Clients/IStatisticsClient.cs
+++ b/Octokit/Clients/IStatisticsClient.cs
@@ -6,11 +6,11 @@ namespace Octokit
public interface IStatisticsClient
{
///
/// Returns a list of for the given repo
///
/// The owner of the repository
- /// The name of the repository
+ /// The name of the repository
/// A list of
- Task> Contributors(string owner, string repoName);
+ Task> Contributors(string owner, string repositoryName);
}
}
\ No newline at end of file
@@ -6,11 +6,11 @@ namespace Octokit
{
///
- /// Returns a list of for the given repo
+ /// Returns a list of for the given repository
///
/// The owner of the repository